# Waiting Period
| State | Waiting Period Hours | Counseling Visits | Exception Health | Waiting Period Notes | Last Updated | 
| ----- | -------------------- | ----------------- | ---------------- | -------------------- | ------------ |
| Alabama | 48 | 1 | No | N/A | No date available |
| Alaska | N/A | 1 | No | N/A | 2022-02-15T21:04:41.000Z |
| Arizona | 24 | 2 | No | N/A | No date available |
| Arkansas | 72 | 2 | No | N/A | 2019-11-13T12:13:26.000Z |
| Florida | 24 | 2 | No | N/A | 2022-04-04T14:57:11.000Z |
| Georgia | 24 | 1 | No | N/A | No date available |
| Idaho | 24 | 1 | No | N/A | No date available |
| Indiana | 18 | 2 | No | N/A | No date available |
| Iowa | 24 | 1 | No | N/A | 2022-06-18T17:06:11.000Z |
| Kansas | 24 | 1 | No | N/A | No date available |
| Kentucky | 24 | 2 | No | N/A | No date available |
| Louisiana | 72 | 2 | No | N/A | 2022-06-16T13:15:50.000Z |
| Michigan | 24 | 1 | No | N/A | No date available |
| Minnesota | 24 | 1 | No | N/A | No date available |
| Mississippi | 24 | 2 | No | N/A | No date available |
| Missouri | 72 | 2 | No | N/A | No date available |
| Nebraska | 24 | 1 | No | N/A | No date available |
| North Carolina | 72 | 1 | No | N/A | No date available |
| North Dakota | 24 | 1 | No | N/A | No date available |
| Ohio | 24 | 2 | No | N/A | No date available |
| Oklahoma | 72 | 1 | No | N/A | No date available |
| Pennsylvania | 24 | 1 | No | N/A | No date available |
| South Carolina | 24 | 1 | No | N/A | No date available |
| South Dakota | 72 | 2 | No | Weekends and holidays do not count towards the 72-hour waiting period. | No date available |
| Tennessee | 48 | 2 | No | N/A | No date available |
| Texas | 24 | 2 | No | N/A | No date available |
| Utah | 72 | 2 | No | N/A | No date available |
| Virginia | N/A | N/A | No | N/A | 2020-07-06T15:57:47.000Z |
| West Virginia | 24 | 1 | No | N/A | No date available |
| Wisconsin | 24 | 2 | No | N/A | No date available |